@@ -128,7 +128,7 @@ class QCollapsible(QFrame):
         self._animation.setDuration(msecs)
 
     def setEasingCurve(self, easing: QEasingCurve) -> None:
-        """Set the easing curve for the collapse/expand animation"""
+        """Set the easing curve for the collapse/expand animation."""
         self._animation.setEasingCurve(easing)
 
     def addWidget(self, widget: QWidget) -> None:
@@ -142,11 +142,11 @@ class QCollapsible(QFrame):
         widget.removeEventFilter(self)
 
     def expand(self, animate: bool = True) -> None:
-        """Expand (show) the collapsible section"""
+        """Expand (show) the collapsible section."""
         self._expand_collapse(QPropertyAnimation.Direction.Forward, animate)
 
     def collapse(self, animate: bool = True) -> None:
-        """Collapse (hide) the collapsible section"""
+        """Collapse (hide) the collapsible section."""
         self._expand_collapse(QPropertyAnimation.Direction.Backward, animate)
 
     def isExpanded(self) -> bool:
@@ -154,7 +154,7 @@ class QCollapsible(QFrame):
         return self._toggle_btn.isChecked()
 
     def setLocked(self, locked: bool = True) -> None:
-        """Set whether collapse/expand is disabled"""
+        """Set whether collapse/expand is disabled."""
         self._locked = locked
         self._toggle_btn.setCheckable(not locked)
 
@@ -172,7 +172,8 @@ class QCollapsible(QFrame):
 
         An emit flag is included so that the toggle signal is only called once (it
         was being emitted a few times via eventFilter when the widget was expanding
-        previously)."""
+        previously).
+        """
         if self._locked:
             return
 
