@@ -1,3 +1,4 @@
+import contextlib
 from enum import IntEnum
 from functools import partial
 from typing import Any
@@ -17,7 +18,8 @@ from qtpy.QtWidgets import (
     QWidget,
 )
 
-from ..utils import signals_blocked
+from superqt.utils import signals_blocked
+
 from ._sliders import QDoubleRangeSlider, QDoubleSlider, QRangeSlider
 
 
@@ -129,6 +131,9 @@ class QLabeledSlider(_SliderProxy, QAbstractSlider):
         parent, orientation = _handle_overloaded_slider_sig(args, kwargs)
 
         super().__init__(parent)
+        # accept focus events
+        fp = self.style().styleHint(QStyle.StyleHint.SH_Button_FocusPolicy)
+        self.setFocusPolicy(Qt.FocusPolicy(fp))
 
         self._slider = self._slider_class()
         self._label = SliderLabel(self._slider, connect=self._setValue)
@@ -219,6 +224,10 @@ class QLabeledDoubleSlider(QLabeledSlider):
         super().__init__(*args, **kwargs)
         self.setDecimals(2)
 
+    def _setValue(self, value: float):
+        """Convert the value from float to int before setting the slider value."""
+        self._slider.setValue(value)
+
     def _rename_signals(self):
         self.valueChanged = self._fvalueChanged
         self.sliderMoved = self._fsliderMoved
@@ -565,10 +574,8 @@ class SliderLabel(QDoubleSpinBox):
         if opt == EdgeLabelMode.LabelIsRange:
             self.setMinimum(-9999999)
             self.setMaximum(9999999)
-            try:
+            with contextlib.suppress(Exception):
                 self._slider.rangeChanged.disconnect(self.setRange)
-            except Exception:
-                pass
         else:
             self.setMinimum(self._slider.minimum())
             self.setMaximum(self._slider.maximum())
